from setuptools import setup,find_packages

setup(
    name="my_pqr_package_ashjaa",
    description="this package is custom package with some functions",
    version=1.01,
    packages=find_packages(),
    author="ashjaa khan",
    author_email="ashjaakhan@gmail.com"
)